==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/QGpGuiMath/src/RealStatisticalPlotProxy.cpp <==
/***************************************************************************
**
**  This file is part of QGpGuiMath.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2016-09-16
**  Copyright: 2016-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "RealStatisticalPlotProxy.h"

namespace QGpGuiMath {

  /*!
    \class RealStatisticalPlotProxy RealStatisticalPlotProxy.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  void RealStatisticalPlotProxy::setCurve(AbstractLine * line, CurveProxy * proxy)
  {
    TRACE;
    static_cast<RealStatisticalProxy *>(proxy)->setCurve(&static_cast<RealStatisticalLine *>(line)->curve());
  }

} // namespace QGpGuiMath

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/QGpGuiMath/src/RealStatisticalPlotProxy.cpp <==
/***************************************************************************
**
**  This file is part of QGpGuiMath.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2016-09-16
**  Copyright: 2016-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "RealStatisticalPlotProxy.h"

namespace QGpGuiMath {

  /*!
    \class RealStatisticalPlotProxy RealStatisticalPlotProxy.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  void RealStatisticalPlotProxy::setCurve(AbstractLine * line, CurveProxy * proxy) const
  {
    TRACE;
    static_cast<RealStatisticalProxy *>(proxy)->setCurve(&static_cast<RealStatisticalLine *>(line)->curve());
  }

} // namespace QGpGuiMath
